@@ -9,6 +9,7 @@ from rpy.functions.datastructures import data
 from rpy.functions.encoding import force_bytes
 from rpy.functions.functional import iterate, first
 from rpy.functions.decorators import to_data
+from rpy.functions.importutils import safe_import_string
 
 @to_data
 def _parse_settings(opts):
@@ -19,20 +20,20 @@ def _parse_settings(opts):
     for name, value in opts.items():
         if not isinstance(value, dict):
             l, p = value
-            yield name, data(location = l, password = p)
+            yield name, data(location = os.path.expanduser(l), password = p)
         else:
-            yield name, data(location = value['location'], password = value['password'])
+            yield name, data(location = os.path.expanduser(value['location']), password = value['password'])
 
 
 class KeyChain(object):
 
-    serializer = json
-    cypher = fernet
-
-    def __init__(self, **opts):
+    def __init__(self, serializer = None, cypher = None, **opts):
         self.settings = _parse_settings(opts)
         self.default_name = first(self.settings.keys())
 
+        self.serializer = safe_import_string(serializer or json)
+        self.cypher     = safe_import_string(cypher or fernet)
+
     def loads(self, payload, password):
         return self.serializer.loads(
             self.cypher.loads(payload, password=password))
